@@ -7,11 +7,11 @@
 
 package Bugzilla::Auth::Login::Env;
 
-use 5.10.1;
+use 5.14.0;
 use strict;
 use warnings;
 
-use parent qw(Bugzilla::Auth::Login);
+use base qw(Bugzilla::Auth::Login);
 
 use Bugzilla::Constants;
 use Bugzilla::Error;
